
#define R_E               6371.2  /* Magnetic reference radius  */
#define MAX_0_DEG         740     /* Max degree of static field */
#define MAX_0_NCOEFF      (MAX_0_DEG * (MAX_0_DEG + 2))
#define MAX_V_DEG         20      /* Max degree of time derivatives (all same) */
#define MAX_V_NCOEFF      (MAX_V_DEG * (MAX_V_DEG + 2))

#define MAX_EXT_DEG       3       /* Max degree of external field, limited to 3 */
#define MAX_EXT_NCOEFF    (MAX_EXT_DEG * (MAX_EXT_DEG + 2))  

#define POS_0             0       /* static internal */
#define POS_1             1       /* SV */
#define POS_2             2       /* sec acc before epoch, or for entire period*/
#define POS_3             3       /* sec acc after epoch */
#define POS_SM            4       /* static ring current */
#define POS_SM_IND        5       /* if asymmetric then could induce field, not implemented */
#define POS_EST           6       /* external RC field */
#define POS_IST           7       /* induced RC field */
#define POS_GSM           8       /* external GSM static field */
#define POS_GSM_IND       9       /* induced internal*/
#define POS_IMFBY         10      /* external IMFBY correlated field */
#define POS_IMFBY_IND     11      /* induced internal*/
#define POS_EST_FAC       12      /* factor for Est/Ist field */
#define POS_F107          13      /* external F107 correlated field in SM */
#define POS_F107_IND      14      /* induced internal*/
#define POS_EM            15      /* external Em correlated field in GSM */
#define POS_EM_IND        16      /* induced internal*/
#define MAXCONTROL        17      /* number of control parameters */

#define MAX_S_COEFF       15       /* spatial coefficients, must change also in gsm2geo and sm2geo  */
#define MAX_T_COEFF       13       /* temporal coefficients */
#define MAXPERIOD         7        /* const, 24h, 12h, 8h ..., must change also in gsm2geo and sm2geo*/
#define SM2GEO_MAXNCOEFF  (MAX_S_COEFF*MAX_S_COEFF*MAX_T_COEFF)
#define GSM2GEO_MAXNCOEFF (MAX_S_COEFF*MAX_S_COEFF*MAX_T_COEFF*MAX_T_COEFF)

#define CONVENTION        1.0       /* 1.0 for exp(iwt), -1.0 for exp(-iwt) */

#define EM_MEAN         0.5         /*Will be subtracted to get variation around mean*/
#define EM_PEAK           8         /*mV/m, used Em approaches this peak assymptotically*/
#define F107_MEAN       120.0       /*Will be subtracted to get variation around mean*/


typedef int tcontrol[MAXCONTROL];
typedef double tgsm2geo_coeff[GSM2GEO_MAXNCOEFF];
typedef double tgsm2geo_green[MAX_S_COEFF][MAX_S_COEFF][MAXPERIOD];    /*nc,nc, (const, 24h, 12h, 8h), synchronize with gsn2geo.c*/
typedef double tsm2geo_coeff[SM2GEO_MAXNCOEFF];

typedef struct tmodel
{
  int deg_imfby, deg_Em, deg_f107, deg_sm, deg_gsm, deg_int, deg_1st, deg_2nd, deg_2nd_plus;
  double ref_day, first_day, last_day;
  double imfby[3]; 
  double est_fac;
  double f107[MAX_EXT_NCOEFF],Em[MAX_EXT_NCOEFF],sm[MAX_EXT_NCOEFF],gsm[MAX_EXT_NCOEFF];
  double g[MAX_0_NCOEFF],gs[MAX_V_NCOEFF],gssm[MAX_V_NCOEFF],gssp[MAX_V_NCOEFF];
  int sm2geo_deg_ext, sm2geo_deg_day;
  tsm2geo_coeff coeff_sm2geo;
  int gsm2geo_deg_ext, gsm2geo_deg_day, gsm2geo_deg_ann;
  tgsm2geo_coeff coeff_gsm2geo;
} tmodel;
